# spin-and-heave  
  
use lambdaci docker image to package and zip lambda package, then run terraform apply.  
  
### usage  

`$ spin-and-heave lambda_project`  

*where "lambda_project" is the directory with your lambda files  
this will run the lambdaci docker image for the runtime you're using  
then save the zip file (in this case "lambda_project.zip") in your current  
working directory*  
  
`$ spin-and-heave lambda_project -s`  
  
*skip terraform apply*  
  
`$ spin-and-heave lambda_project -js`  
  
*spin and heave a node lambda package, defaults to nodejs10.x  
this will run "npm install --production" instead of "pip install"*  
  
`$ spin-and-heave lambda_project -r python3.7`  
  
*alternatively, use custom runtimes.  
this has no real use yet...   
only python and node would be supported thus far*
